@@ -1,45 +1,49 @@
-context("f7Block")
-
 test_that("block class", {
   expect_true(inherits(f7Block(), "shiny.tag"))
   expect_equal(f7Block()$attribs$class, "block")
 
-  # no hairlines, strong, inset, tablet
+  expect_error(f7Block(inset = FALSE, tablet = TRUE))
+  expect_error(f7Block(inset = TRUE))
+
+  # basic
+  expect_equal(
+    f7Block()$attribs$class,
+    "block"
+  )
+
+  # strong, inset
+  expect_equal(
+    f7Block(
+      strong = TRUE,
+      inset = TRUE
+    )$attribs$class,
+    "block block-strong inset"
+  )
+
+  # strong, inset, tablet, outline
   expect_equal(
     f7Block(
-      hairlines = FALSE,
       strong = TRUE,
       inset = TRUE,
       tablet = TRUE,
+      outline = TRUE,
     )$attribs$class,
-    "block no-hairlines block-strong inset tablet-inset"
-  )
-
-  # no inset
-  expect_equal(
-    f7Block(
-      hairlines = FALSE,
-      strong = TRUE,
-      inset = FALSE,
-      tablet = TRUE,
-    )$attribs$class,
-    "block no-hairlines block-strong tablet-inset"
+    "block block-strong medium-inset block-outline"
   )
 })
 
-
 test_that("blocktitle", {
-  expect_true(inherits(f7BlockTitle(), "shiny.tag"))
+  expect_true(inherits(f7BlockTitle("plop"), "shiny.tag"))
   expect_equal(
-    f7BlockTitle()$attribs$class,
+    f7BlockTitle("plop")$attribs$class,
     "block-title"
   )
   expect_equal(
-    f7BlockTitle(size = "large")$attribs$class,
+    f7BlockTitle("plop", size = "large")$attribs$class,
     "block-title block-title-large"
   )
   expect_equal(
-    f7BlockTitle(size = "medium")$attribs$class,
+    f7BlockTitle("plop", size = "medium")$attribs$class,
     "block-title block-title-medium"
   )
 })
